==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/d38/newgrf__debug__data_8h.js <==
var newgrf__debug__data_8h =
[
    [ "NIHVehicle", "db/da3/classNIHVehicle.html", "db/da3/classNIHVehicle" ],
    [ "NIHStation", "d3/d7a/classNIHStation.html", "d3/d7a/classNIHStation" ],
    [ "NIHHouse", "d5/d85/classNIHHouse.html", "d5/d85/classNIHHouse" ],
    [ "NIHIndustryTile", "d3/d20/classNIHIndustryTile.html", "d3/d20/classNIHIndustryTile" ],
    [ "NIHIndustry", "d9/dfc/classNIHIndustry.html", "d9/dfc/classNIHIndustry" ],
    [ "NIHObject", "d1/d2e/classNIHObject.html", "d1/d2e/classNIHObject" ],
    [ "NIHRailType", "df/d43/classNIHRailType.html", "df/d43/classNIHRailType" ],
    [ "NIHAirportTile", "d7/dee/classNIHAirportTile.html", "d7/dee/classNIHAirportTile" ],
    [ "NIHTown", "d2/d67/classNIHTown.html", "d2/d67/classNIHTown" ],
    [ "NIC", "d5/d38/newgrf__debug__data_8h.html#a581ed2ca4b8c626eeb8ecd6fb6e3d772", null ],
    [ "NIC_END", "d5/d38/newgrf__debug__data_8h.html#a362257b638fc544a1e5f5014fcd01fef", null ],
    [ "NICAT", "d5/d38/newgrf__debug__data_8h.html#a8429b336ae06aa5a81e875ec76ae42d7", null ],
    [ "NICH", "d5/d38/newgrf__debug__data_8h.html#ac83f22cce283fac1a75ef158fdc03f82", null ],
    [ "NICI", "d5/d38/newgrf__debug__data_8h.html#afc7398c9ef0cc25dc6028691bd3f8cbd", null ],
    [ "NICIT", "d5/d38/newgrf__debug__data_8h.html#a4e6a8159a65575648067ab8752840c0c", null ],
    [ "NICO", "d5/d38/newgrf__debug__data_8h.html#a8450b916a71200d0cd5981d19cb0859c", null ],
    [ "NICS", "d5/d38/newgrf__debug__data_8h.html#a8fc638313aa978cb0d8df5f5f0e0ba6e", null ],
    [ "NICV", "d5/d38/newgrf__debug__data_8h.html#aa955857e1259bbe73e9b2b597b1a845e", null ],
    [ "NIP", "d5/d38/newgrf__debug__data_8h.html#a40849fc71cba76c2789917f4bd4f5cd6", null ],
    [ "NIP_END", "d5/d38/newgrf__debug__data_8h.html#a244246ff68c55a6af19b97b3bed0bc26", null ],
    [ "NIV", "d5/d38/newgrf__debug__data_8h.html#aeb25ef935151baa4cc5b2fb3d33a64fd", null ],
    [ "NIV_END", "d5/d38/newgrf__debug__data_8h.html#af7454aa3a4394ea21fad568f7f868d45", null ],
    [ "assert_compile", "d5/d38/newgrf__debug__data_8h.html#afcb06382f4ccc40f45b5fab805c25897", null ],
    [ "_nic_airporttiles", "d5/d38/newgrf__debug__data_8h.html#ad3bce2661d007ab03aa0c90b40c0b3da", null ],
    [ "_nic_house", "d5/d38/newgrf__debug__data_8h.html#aedc85ed00ac7894c6f87c4f82668c491", null ],
    [ "_nic_industries", "d5/d38/newgrf__debug__data_8h.html#ab88b514ff07fae3e4cdfc3fed9f4318d", null ],
    [ "_nic_industrytiles", "d5/d38/newgrf__debug__data_8h.html#aadb05db7d05021def435d408a8a6bb5f", null ],
    [ "_nic_objects", "d5/d38/newgrf__debug__data_8h.html#ad16b25580523dd52f5192e94e17827d0", null ],
    [ "_nic_stations", "d5/d38/newgrf__debug__data_8h.html#a397e0ce0a398e8a65ab98be28d58111c", null ],
    [ "_nic_vehicles", "d5/d38/newgrf__debug__data_8h.html#ab95a6a02503899c6d3a9deec0b74348e", null ],
    [ "_nif_airporttile", "d5/d38/newgrf__debug__data_8h.html#a5e115587dd1f4e3a207cc94256091672", null ],
    [ "_nif_house", "d5/d38/newgrf__debug__data_8h.html#a659b175394fadd3f46b3a8bd4d85fcab", null ],
    [ "_nif_industry", "d5/d38/newgrf__debug__data_8h.html#a02fc0f4130b38c0e7f950b3c3dbab096", null ],
    [ "_nif_industrytile", "d5/d38/newgrf__debug__data_8h.html#a2c9e8f269f809fbe8ee6a95a059c577e", null ],
    [ "_nif_object", "d5/d38/newgrf__debug__data_8h.html#a3a3d85aed52ad7b253032f27d15217c3", null ],
    [ "_nif_railtype", "d5/d38/newgrf__debug__data_8h.html#aefd21be7dff1f6aa30f33e31d53abb56", null ],
    [ "_nif_station", "d5/d38/newgrf__debug__data_8h.html#af7259c9bb2f2de85ff4b40f097bc6eca", null ],
    [ "_nif_town", "d5/d38/newgrf__debug__data_8h.html#af2c0cb347b1d2ffec005b5fe71a52ec8", null ],
    [ "_nif_vehicle", "d5/d38/newgrf__debug__data_8h.html#a3beca3946317607ba34c2a30ae9eb58d", null ],
    [ "_nifeatures", "d5/d38/newgrf__debug__data_8h.html#a4685da6f11409450f136ea301a2c2eb1", null ],
    [ "_nip_industries", "d5/d38/newgrf__debug__data_8h.html#a9150a3703b0abd314d1280688a5567a6", null ],
    [ "_niv_house", "d5/d38/newgrf__debug__data_8h.html#a363866e32c4c0f37e2f5135005e882cc", null ],
    [ "_niv_industries", "d5/d38/newgrf__debug__data_8h.html#a3226c332caf4b6abae338c1ef85d5399", null ],
    [ "_niv_industrytiles", "d5/d38/newgrf__debug__data_8h.html#a5550ae925e7e20fd3c84e8c1f88c9efc", null ],
    [ "_niv_objects", "d5/d38/newgrf__debug__data_8h.html#a9b9427f70b3b7ceb69f0a55cc5adee9c", null ],
    [ "_niv_railtypes", "d5/d38/newgrf__debug__data_8h.html#ab273142d5597e3e813ca7c3b47549054", null ],
    [ "_niv_stations", "d5/d38/newgrf__debug__data_8h.html#a9ebb7632d627c013f42495927965e348", null ],
    [ "_niv_towns", "d5/d38/newgrf__debug__data_8h.html#ad5ada43dc55a81608e9ad6348913e93b", null ],
    [ "_niv_vehicles", "d5/d38/newgrf__debug__data_8h.html#a8766d3d42ee4f50b69e2d3d97ea45c8e", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/d38/newgrf__debug__data_8h.js <==
var newgrf__debug__data_8h =
[
    [ "NIHVehicle", "db/da3/classNIHVehicle.html", "db/da3/classNIHVehicle" ],
    [ "NIHStation", "d3/d7a/classNIHStation.html", "d3/d7a/classNIHStation" ],
    [ "NIHHouse", "d5/d85/classNIHHouse.html", "d5/d85/classNIHHouse" ],
    [ "NIHIndustryTile", "d3/d20/classNIHIndustryTile.html", "d3/d20/classNIHIndustryTile" ],
    [ "NIHIndustry", "d9/dfc/classNIHIndustry.html", "d9/dfc/classNIHIndustry" ],
    [ "NIHObject", "d1/d2e/classNIHObject.html", "d1/d2e/classNIHObject" ],
    [ "NIHRailType", "df/d43/classNIHRailType.html", "df/d43/classNIHRailType" ],
    [ "NIHAirportTile", "d7/dee/classNIHAirportTile.html", "d7/dee/classNIHAirportTile" ],
    [ "NIHTown", "d2/d67/classNIHTown.html", "d2/d67/classNIHTown" ],
    [ "NIHRoadType", "db/d25/classNIHRoadType.html", "db/d25/classNIHRoadType" ],
    [ "NIC", "d5/d38/newgrf__debug__data_8h.html#a581ed2ca4b8c626eeb8ecd6fb6e3d772", null ],
    [ "NIC_END", "d5/d38/newgrf__debug__data_8h.html#a362257b638fc544a1e5f5014fcd01fef", null ],
    [ "NICAT", "d5/d38/newgrf__debug__data_8h.html#a8429b336ae06aa5a81e875ec76ae42d7", null ],
    [ "NICH", "d5/d38/newgrf__debug__data_8h.html#ac83f22cce283fac1a75ef158fdc03f82", null ],
    [ "NICI", "d5/d38/newgrf__debug__data_8h.html#afc7398c9ef0cc25dc6028691bd3f8cbd", null ],
    [ "NICIT", "d5/d38/newgrf__debug__data_8h.html#a4e6a8159a65575648067ab8752840c0c", null ],
    [ "NICO", "d5/d38/newgrf__debug__data_8h.html#a8450b916a71200d0cd5981d19cb0859c", null ],
    [ "NICS", "d5/d38/newgrf__debug__data_8h.html#a8fc638313aa978cb0d8df5f5f0e0ba6e", null ],
    [ "NICV", "d5/d38/newgrf__debug__data_8h.html#aa955857e1259bbe73e9b2b597b1a845e", null ],
    [ "NIP", "d5/d38/newgrf__debug__data_8h.html#a40849fc71cba76c2789917f4bd4f5cd6", null ],
    [ "NIP_END", "d5/d38/newgrf__debug__data_8h.html#a244246ff68c55a6af19b97b3bed0bc26", null ],
    [ "NIV", "d5/d38/newgrf__debug__data_8h.html#aeb25ef935151baa4cc5b2fb3d33a64fd", null ],
    [ "NIV_END", "d5/d38/newgrf__debug__data_8h.html#af7454aa3a4394ea21fad568f7f868d45", null ],
    [ "_nic_airporttiles", "d5/d38/newgrf__debug__data_8h.html#ad3bce2661d007ab03aa0c90b40c0b3da", null ],
    [ "_nic_house", "d5/d38/newgrf__debug__data_8h.html#aedc85ed00ac7894c6f87c4f82668c491", null ],
    [ "_nic_industries", "d5/d38/newgrf__debug__data_8h.html#ab88b514ff07fae3e4cdfc3fed9f4318d", null ],
    [ "_nic_industrytiles", "d5/d38/newgrf__debug__data_8h.html#aadb05db7d05021def435d408a8a6bb5f", null ],
    [ "_nic_objects", "d5/d38/newgrf__debug__data_8h.html#ad16b25580523dd52f5192e94e17827d0", null ],
    [ "_nic_stations", "d5/d38/newgrf__debug__data_8h.html#a397e0ce0a398e8a65ab98be28d58111c", null ],
    [ "_nic_vehicles", "d5/d38/newgrf__debug__data_8h.html#ab95a6a02503899c6d3a9deec0b74348e", null ],
    [ "_nif_airporttile", "d5/d38/newgrf__debug__data_8h.html#a5e115587dd1f4e3a207cc94256091672", null ],
    [ "_nif_house", "d5/d38/newgrf__debug__data_8h.html#a659b175394fadd3f46b3a8bd4d85fcab", null ],
    [ "_nif_industry", "d5/d38/newgrf__debug__data_8h.html#a02fc0f4130b38c0e7f950b3c3dbab096", null ],
    [ "_nif_industrytile", "d5/d38/newgrf__debug__data_8h.html#a2c9e8f269f809fbe8ee6a95a059c577e", null ],
    [ "_nif_object", "d5/d38/newgrf__debug__data_8h.html#a3a3d85aed52ad7b253032f27d15217c3", null ],
    [ "_nif_railtype", "d5/d38/newgrf__debug__data_8h.html#aefd21be7dff1f6aa30f33e31d53abb56", null ],
    [ "_nif_roadtype", "d5/d38/newgrf__debug__data_8h.html#a1641c7d00a8aca061b77be9a7e6026a5", null ],
    [ "_nif_station", "d5/d38/newgrf__debug__data_8h.html#af7259c9bb2f2de85ff4b40f097bc6eca", null ],
    [ "_nif_town", "d5/d38/newgrf__debug__data_8h.html#af2c0cb347b1d2ffec005b5fe71a52ec8", null ],
    [ "_nif_tramtype", "d5/d38/newgrf__debug__data_8h.html#a3217812f73acd7b727438f9cb312b585", null ],
    [ "_nif_vehicle", "d5/d38/newgrf__debug__data_8h.html#a3beca3946317607ba34c2a30ae9eb58d", null ],
    [ "_nifeatures", "d5/d38/newgrf__debug__data_8h.html#a4685da6f11409450f136ea301a2c2eb1", null ],
    [ "_nip_industries", "d5/d38/newgrf__debug__data_8h.html#a9150a3703b0abd314d1280688a5567a6", null ],
    [ "_niv_house", "d5/d38/newgrf__debug__data_8h.html#a363866e32c4c0f37e2f5135005e882cc", null ],
    [ "_niv_industries", "d5/d38/newgrf__debug__data_8h.html#a3226c332caf4b6abae338c1ef85d5399", null ],
    [ "_niv_industrytiles", "d5/d38/newgrf__debug__data_8h.html#a5550ae925e7e20fd3c84e8c1f88c9efc", null ],
    [ "_niv_objects", "d5/d38/newgrf__debug__data_8h.html#a9b9427f70b3b7ceb69f0a55cc5adee9c", null ],
    [ "_niv_railtypes", "d5/d38/newgrf__debug__data_8h.html#ab273142d5597e3e813ca7c3b47549054", null ],
    [ "_niv_roadtypes", "d5/d38/newgrf__debug__data_8h.html#aefb3e6629aeaf2e1efd8688e2acf6e4a", null ],
    [ "_niv_stations", "d5/d38/newgrf__debug__data_8h.html#a9ebb7632d627c013f42495927965e348", null ],
    [ "_niv_towns", "d5/d38/newgrf__debug__data_8h.html#ad5ada43dc55a81608e9ad6348913e93b", null ],
    [ "_niv_vehicles", "d5/d38/newgrf__debug__data_8h.html#a8766d3d42ee4f50b69e2d3d97ea45c8e", null ]
];
